@@ -133,6 +133,11 @@ pub fn get_config() -> (Config, usize) {
             Arg::with_name("disable-progress-bar")
                 .long("disable-progress-bar")
         )
+        .arg(
+            Arg::with_name("keep-newlines")
+                .long("keep-newlines")
+                .help("--body 'a\\r\\nb' -> --body 'a{{new_line}}b'.\nWorks with body and parameter templates only")
+            )
         .arg(
             Arg::with_name("replay-once")
                 .long("replay-once")
@@ -228,6 +233,7 @@ pub fn get_config() -> (Config, usize) {
             Arg::with_name("http2")
                 .long("http2")
                 .help("Prefer http/2 over http/1.1")
+                .conflicts_with("request")
         );
 
     let args = app.clone().get_matches();
@@ -341,20 +347,31 @@ pub fn get_config() -> (Config, usize) {
     let host = url.host_str().unwrap();
     let mut path = url[url::Position::BeforePath..].to_string();
 
-    let body = args.value_of("body").unwrap_or("");
+    let body = match args.is_present("keep-newlines") {
+        true => args.value_of("body").unwrap_or("")/*.replace("\\\\", "\\")*/.replace("\\n", "\n").replace("\\r", "\r"),
+        false => args.value_of("body").unwrap_or("").to_string()
+    };
 
     //check whether it is possible to automatically fix body type
     //- at the end means "specified automatically"
-    let body_type = if args.value_of("body-type").is_none() && !body.is_empty() && body.starts_with('{') {
+    let body_type = if args.value_of("body-type").is_none() && args.value_of("parameter_template").unwrap_or("").is_empty()
+        && (
+            (
+                !body.is_empty() && body.starts_with('{')
+            )
+            || (
+                headers.contains_key("Content-Type") && headers["Content-Type"].contains("json")
+            )
+        ) {
         String::from("json-")
     } else {
         args.value_of("body-type").unwrap_or("urlencode-").to_string()
     };
 
     let body = if !body.contains("%s") && args.is_present("as-body") {
-        adjust_body(body, &body_type)
+        adjust_body(&body, &body_type)
     } else {
-        body.to_string()
+        body
     };
 
     //set default headers if weren't specified by a user.
@@ -407,7 +424,11 @@ pub fn get_config() -> (Config, usize) {
         path.push_str("?%s");
     }
 
-    let mut parameter_template = args.value_of("parameter_template").unwrap_or("");
+    let parameter_template = match args.is_present("keep-newlines") {
+        true => args.value_of("parameter_template").unwrap_or("").replace("\\n", "\n").replace("\\r", "\r"),
+        false => args.value_of("parameter_template").unwrap_or("").to_string()
+    };
+    let mut parameter_template = parameter_template.as_str();
 
     if !parameter_template.is_empty()
         && (!parameter_template.contains("%k") || !parameter_template.contains("%v"))
@@ -508,7 +529,7 @@ pub fn get_config() -> (Config, usize) {
     };
 
     config = if !request.is_empty() {
-        match parse_request(args.value_of("proto").unwrap_or("https"), &request, config) {
+        match parse_request(config, args.value_of("proto").unwrap_or("https"), &request, !args.value_of("parameter_template").unwrap_or("").is_empty()) {
             Some(val) => val,
             None => {
                 writeln!(io::stderr(), "Unable to parse request file.").ok();
